import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

import unittest
import CPSSkinsTestCase

class TestTemplets(CPSSkinsTestCase.CPSSkinsTestCase):

    def afterSetUp(self):
        tmtool = self.portal.portal_themes
        if 'PortalTheme' in tmtool.objectIds():
           tmtool.manage_delObjects(['PortalTheme'])
        self.theme_container = tmtool.addPortalTheme()
        self.pageblock = self.theme_container.addPageBlock()
        self.portal.REQUEST.SESSION = {}
        self.portal.REQUEST.set('cpsskins_mcat', self.portal.cpsskins_getlocalizer())


    def test_1(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Main Content Templet')
        self.assertEquals('Main Content Templet', getattr(templet, 'title'))
        self.assert_(templet.aq_explicit.isPortalTemplet())
        self.assert_(templet.render())

    def test_2(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Search Box Templet')
        self.assertEquals('Search Box Templet', getattr(templet, 'title'))
        self.assert_(templet.aq_explicit.isPortalTemplet())
        self.assertEquals(templet.getApplicableStyles(), \
            ['Font Color', 'Font Shape', 'Area Shape', 'Area Color'])
        for style in ['compact', 'advanced']:
            templet.style = style
            self.assert_(templet.render())

    def test_3(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        self.assertEquals('Text Box Templet', getattr(templet, 'title'))
        self.assert_(templet.aq_explicit.isPortalTemplet())
        self.assertEquals(templet.getApplicableStyles(), \
            ['Font Color', 'Font Shape', 'Area Shape', 'Area Color'])
        self.assert_(templet.render())

    def test_4(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Portal Box Templet')
        self.assertEquals('Portal Box Templet', getattr(templet, 'title'))
        self.assert_(templet.aq_explicit.isPortalTemplet())
        self.assert_(templet.aq_explicit.isPortalBox())
        self.assertEquals(templet.getApplicableStyles(), \
            ['Font Color', 'Font Shape', 'Area Shape', 'Area Color', 'Portal Box Shape', 'Portal Box Color'])
        for content in ['actions', 'folders', 'about', 'login', \
                        'login', 'info', 'related', 'recent', 'language']:
            templet.content = content 
            self.assert_(templet.render())
          
    def test_4b(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Portal Box Templet')
        self.assertEquals('Portal Box Templet', getattr(templet, 'title'))
        for title_source in ['Templet title', 'Workflow state', 'Username', 'Folder title']:
            templet.title_source = title_source
            self.assert_(templet.render())

    def test_4c(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Portal Box Templet')
        self.assertEquals('Portal Box Templet', getattr(templet, 'title'))
        for boxlayout in [ 'standard', 'one_frame', 'notitle', 'no_frames', 'notitle_noframe' ]:
            templet.boxlayout = boxlayout
            self.assert_(templet.render())

    def test_5(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Portal Box Group Templet')
        self.assertEquals('Portal Box Group Templet', getattr(templet, 'title'))
        self.assert_(templet.aq_explicit.isPortalTemplet())
        self.assertEquals(templet.getApplicableStyles(), \
            ['Font Color', 'Font Shape', 'Area Shape', 'Area Color', 'Portal Box Shape', 'Portal Box Color'])
        self.assert_(templet.render())

    def test_6(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Language Templet')
        self.assertEquals('Language Templet', getattr(templet, 'title'))
        self.assert_(templet.aq_explicit.isPortalTemplet())
        self.assertEquals(templet.getApplicableStyles(), \
            ['Font Color', 'Font Shape', 'Area Shape', 'Area Color'])
        self.assert_(templet.render())

    def test_7(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Theme Chooser Templet')
        self.assertEquals('Theme Chooser Templet', getattr(templet, 'title'))
        self.assert_(templet.aq_explicit.isPortalTemplet())
        self.assertEquals(templet.getApplicableStyles(), \
            ['Font Color', 'Font Shape', 'Area Shape', 'Area Color'])
        self.assert_(templet.render())

    def test_8(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Image Box Templet')
        self.assert_(templet.aq_explicit.isPortalTemplet())
        self.assert_(templet.aq_explicit.isImageBox())
        self.assertEquals(templet.getApplicableStyles(), \
            ['Font Color', 'Font Shape', 'Area Shape', 'Area Color'])
        self.assert_(templet.render())

    def test_9(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Flash Box Templet')
        self.assert_(templet.aq_explicit.isPortalTemplet())
        self.assert_(templet.aq_explicit.isFlashBox())
        self.assertEquals(templet.getApplicableStyles(), \
            ['Font Color', 'Font Shape', 'Area Shape', 'Area Color'])
        self.assert_(templet.render())

    def test_10(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Breadcrumbs Templet')
        self.assertEquals('Breadcrumbs Templet', getattr(templet, 'title'))
        self.assert_(templet.aq_explicit.isPortalTemplet())
        self.assertEquals(templet.getApplicableStyles(), \
            ['Font Color', 'Font Shape', 'Area Shape', 'Area Color'])
        self.assert_(templet.render())

    def test_11(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Action Box Templet')
        self.assertEquals('Action Box Templet', getattr(templet, 'title'))
        self.assert_(templet.aq_explicit.isPortalTemplet())
        self.assertEquals(templet.getApplicableStyles(), \
            ['Font Color', 'Font Shape', 'Area Shape', 'Area Color'])
        templet.edit(orientation='horizontal')
        self.assert_(templet.render())
        templet.edit(orientation='vertical')
        self.assert_(templet.render())

    def test_12(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Document Info Templet')
        self.assertEquals('Document Info Templet', getattr(templet, 'title'))
        self.assert_(templet.aq_explicit.isPortalTemplet())
        self.assertEquals(templet.getApplicableStyles(), \
            ['Font Color', 'Font Shape', 'Area Shape', 'Area Color'])
        self.assert_(templet.render())

    def test_13(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Collapsible Menu Templet')
        self.assertEquals('Collapsible Menu Templet', getattr(templet, 'title'))
        self.assert_(templet.aq_explicit.isPortalTemplet())
        self.assertEquals(templet.getApplicableStyles(), \
            ['Font Color', 'Font Shape', 'Area Shape', 'Area Color', 'Collapsible Menu Style'])
        self.assert_(templet.render())

    def test_14(self):
        if 'portal_calendar' in self.portal.objectIds():
           pageblock = self.pageblock
           templet = pageblock.addTemplet(type_name='Calendar Templet')
           self.assertEquals('Calendar Templet', getattr(templet, 'title'))
           self.assert_(templet.aq_explicit.isPortalTemplet())
           self.assertEquals(templet.getApplicableStyles(), \
               ['Font Color', 'Font Shape', 'Area Shape', 'Area Color', 'Calendar Style'])
           self.assert_(templet.render())

    def test_15(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        templet.change_alignment('left')
        self.assertEquals(getattr(templet, 'align'), 'left')
        templet.change_alignment('center')
        self.assertEquals(getattr(templet, 'align'), 'center')
        templet.change_alignment('right')
        self.assertEquals(getattr(templet, 'align'), 'right')
        templet.change_alignment('dummy')
        self.assertEquals(getattr(templet, 'align'), 'right')

    def test_16(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        dest_pageblock = self.theme_container.addPageBlock()
        templet.move_to_pageblock(dest_pageblock, int(0), int(1))
        templet.move_to_pageblock(pageblock, int(0), int(0))

    def test_17(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        templet.duplicate()
        templets = pageblock.objectValues()
        templet_titles = [t.getTitle() for t in templets]
        self.assertEquals(templet_titles, \
                         ['Text Box Templet', 'Text Box Templet'])
      
    def test_18(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        templet.toggle(state=1)
        templet.toggle(state=0)

    def test_19(self):
        pageblock = self.pageblock
        templet1 = pageblock.addTemplet(type_name='Text Box Templet', \
                                        ypos=int(0))
        templet2 = pageblock.addTemplet(type_name='Text Box Templet', \
                                        ypos=int(1))
        templet3 = pageblock.addTemplet(type_name='Text Box Templet', \
                                        ypos=int(2))
        pos1 = templet1.getTempletPosition()
        pos2 = templet2.getTempletPosition()
        pos3 = templet3.getTempletPosition()
        self.assertEquals(pos1, int(0))
        self.assertEquals(pos2, int(1))
        self.assertEquals(pos3, int(2))

    def test_20(self):
        pageblock = self.pageblock
        templet = pageblock.addTemplet(type_name='Text Box Templet', \
                                       ypos=int(0))
        templet.rebuild()


def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(TestTemplets))
    return suite

if __name__ == '__main__':
    framework(descriptions=1, verbosity=2)

